@@ -1,10 +1,11 @@
 """IBM Backend"""
 
 import math
+import uuid
 
 from qutrunk.backends import Backend
 from qutrunk.circuit.gates import CNOT, H, Measure, Rx, Ry, Rz
-from qutrunk.backends.result import MeasureResult, MeasureCount, MeasureQubits, MeasureQubit
+from qutrunk.backends.result import MeasureResult, MeasureQubits
 from .ibm_client import send
 
 
@@ -54,6 +55,7 @@ class BackendIBM(Backend):
         self._json = []
         # measured qubit id
         self._measured_ids = []
+        self.task_id = uuid.uuid4().hex
 
     def send_circuit(self, circuit, final=False):
         """Send the quantum circuit to IBM backend.
@@ -146,7 +148,7 @@ class BackendIBM(Backend):
         counts = res["data"]["counts"]
 
         for bit_str, count in counts:
-            result.measure_counts.append(MeasureCount(bit_str, count))
+            result.measure_counts[bit_str] = count
         return result
 
     @property
