@@ -6,7 +6,7 @@ from qutrunk.backends.backend import Backend
 from qutrunk.tools.read_qubox import get_qubox_setting
 from .rpcclient import QuSproutApiServer
 from qutrunk.thrift.qusproutdata import ttypes as qusproutdata
-from qutrunk.backends.result import MeasureQubit, MeasureQubits, MeasureResult
+from qutrunk.backends.result import MeasureQubits, MeasureResult
 
 
 class BackendQuSprout(Backend):
@@ -190,7 +190,7 @@ class BackendQuSprout(Backend):
             self.circuit.counter.finish()
 
         if res.base.code != 0:
-            raise Exception("Circuit run failed.")
+            raise Exception(f"Circuit run failed, {res.base.msg}")
 
         result = MeasureResult()
         if (
@@ -202,8 +202,7 @@ class BackendQuSprout(Backend):
                 meas_temp = MeasureQubits()
                 if meas.measure is not None:
                     for mea in meas.measure:
-                        mea_temp = MeasureQubit(mea.idx, mea.value)
-                        meas_temp.measure.append(mea_temp)
+                        meas_temp.add_measure(mea.idx, mea.value)
                     result.measures.append(meas_temp)
         """
         1 必须释放连接，不然其它连接无法连上服务端
@@ -253,6 +252,34 @@ class BackendQuSprout(Backend):
             self.circuit.counter.acc_run_time(elapsed)
         return res
 
+    def get_rand(self, length, cnt=1):
+        """
+        generate random number by QuDoor RandomCard integrated in QuSprout
+
+        Args:
+            length: length of the random number
+            cnt: amount of random number
+
+        Examples:
+            .. code-block:: python
+
+                from qutrunk.backends import BackendQuSprout
+
+                be = BackendQuSprout(ip='your QuBox ip', port=9091)
+                rands = be.get_rand(21, 2)
+                print(rands)
+
+        Returns:
+            list of random numbers
+
+        """
+        res = self._api_server.get_rand(length, cnt)
+
+        if res.base.code != 0:
+            raise Exception(f"get_rand failed, {res.base.msg}")
+
+        return res.randoms
+
     @property
     def name(self):
         return "BackendQuSprout-" + self.run_mode
