@@ -80,7 +80,7 @@ class Power(BasicGate):
 
 
 class Matrix(BasicGate):
-    """Custom matrix gate.
+    """Customized matrix gate.
 
     Example:
             .. code-block:: python
@@ -90,10 +90,11 @@ class Matrix(BasicGate):
                 Matrix([[0.5, 0.5], [0.5, -0.5]]).ctrl(2) * (qr[0], qr[1], qr[2])  -- qr[0], qr[1] are controlled bits
     """
 
-    def __init__(self, matrix):
+    def __init__(self, matrix, name = None):
         super().__init__()
         self.matrix = matrix
         self.ctrl_cnt = 0
+        self.name = "Mat" if name is None else name
 
     def __str__(self):
         return "Matrix"
@@ -102,7 +103,7 @@ class Matrix(BasicGate):
         """Quantum logic gate operation.
 
         Args:
-            qubit: The quantum bit to apply X gate.
+            qubits: The quantum bit to apply X gate.
 
         Raises:
             NotImplementedError: If the argument is not a Qubit object.
@@ -112,6 +113,7 @@ class Matrix(BasicGate):
         ):
             raise TypeError("The argument must be Qubit object.")
 
+        # TODO: need to improve.
         if (isinstance(qubits, QuBit) and self.ctrl_cnt > 0) or (
             not isinstance(qubits, QuBit) and (len(qubits) <= self.ctrl_cnt)
         ):
@@ -155,7 +157,7 @@ class Matrix(BasicGate):
 
     def inv(self):
         """Apply inverse gate."""
-        gate = Matrix(self.matrix)
+        gate = Matrix(self.matrix, self.name)
         gate.ctrl_cnt = self.ctrl_cnt
         gate.is_inverse = not self.is_inverse
         return gate
@@ -166,7 +168,7 @@ class Matrix(BasicGate):
         Args:
             ctrl_cnt: The number of control qubits, default: 1.
         """
-        gate = Matrix(self.matrix)
+        gate = Matrix(self.matrix, self.name)
         gate.ctrl_cnt = ctrl_cnt
         gate.is_inverse = self.is_inverse
         return gate
@@ -194,7 +196,10 @@ class Matrix(BasicGate):
                 m = np.matrix(m)
                 print(is_unitary(m))
         """
-        return np.allclose(np.eye(mat.shape[0]), mat.H * mat)
+        mat_dagger = np.conj(mat.T)
+        m = np.allclose(mat_dagger.dot(mat), np.identity(mat.shape[0]))
+        n = np.allclose(mat.dot(mat_dagger), np.identity(mat.shape[0]))
+        return m and n
 
 
 class Gate(BasicGate):
