@@ -35,7 +35,7 @@ class Y1Gate(BasicGate):
             NotImplementedError: If the argument is not a Qubit object.
         """
         if not isinstance(qubit, QuBit):
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         targets = [qubit.index]
         cmd = Command(self, targets, inverse=self.is_inverse)
@@ -50,7 +50,13 @@ class Y1Gate(BasicGate):
     def matrix(self):
         """Access to the matrix property of this gate."""
         factor = 1 / np.sqrt(2)
-        return np.matrix([[factor, -1 * factor], [factor, factor]])
+        return np.array([[factor, -1 * factor], [factor, factor]])
+
+    def inv(self):
+        """Apply inverse gate."""
+        gate = Y1Gate()
+        gate.is_inverse = not self.is_inverse
+        return gate
 
 
 Y1 = Y1Gate()
