@@ -2,6 +2,7 @@
 
 import math
 import random
+import time
 
 from numpy import pi
 
@@ -22,6 +23,7 @@ def run_grover(qubits=10, backend=None):
     print("num_qubits:", num_qubits, "num_elems:", num_elems, "num_reps:", num_reps)
 
     # Choose target state randomly
+    random.seed(int(time.time()))
     sol_elem = random.randint(0, num_elems - 1)
     print(f"target state: |{str(sol_elem)}>")
 
@@ -49,10 +51,10 @@ def run_grover(qubits=10, backend=None):
         print("measure result: " + str(int(out, base=2)))
 
     # Print quantum circuit resource information
-    circuit.show_resource()
+    # circuit.show_resource()
 
     # Print quantum circuit execution information
-    print(res.running_info())
+    # print(res.running_info())
 
     return circuit
 
