@@ -1,4 +1,4 @@
-"""Phase Estimation Example: T-gate"""
+"""Phase Estimation Example: T-gate."""
 
 from math import pi
 
@@ -40,3 +40,4 @@ if __name__ == "__main__":
 
 
 
+
